@@ -30,6 +30,7 @@ class FirstContactHandler:
         except Exception as e:
             raise RuntimeError('Error could not parse version string: "%s" Error: %s' % (version, e))
 
+        self.version = version
         return userid, version
 
     def fetch_courses(self, userid: str) -> [Course]:
@@ -45,7 +46,7 @@ class FirstContactHandler:
 
         results = []
         for course in result:
-            results.append(Course(course.get('id', 0), course.get('fullname', ''), []))
+            results.append(Course(course.get('id', 0), course.get('fullname', '')))
         return results
 
     def fetch_courses_info(self, course_ids: [int]) -> [Course]:
@@ -54,12 +55,13 @@ class FirstContactHandler:
         @param course_ids: A list of courses ids
         @return: A list of courses
         """
-        if len(course_ids) == 0:
+        # API is only available since version 3.2
+        if len(course_ids) == 0 or self.version < 2016120500:
             return []
 
         data = {
             "field": "ids",
-            "value": ",".join(list(map(str, course_ids)))
+            "value": ",".join(list(map(str, course_ids))),
         }
 
         result = self.request_helper.post_REST('core_course_get_courses_by_field', data)
@@ -67,5 +69,5 @@ class FirstContactHandler:
 
         results = []
         for course in result:
-            results.append(Course(course.get('id', 0), course.get('fullname', ''), []))
+            results.append(Course(course.get('id', 0), course.get('fullname', '')))
         return results
